@@ -180,7 +180,7 @@ class DestinationConfig:
             def stub(
                 *,
                 destination_uri: builtins.str,
-                login_config: typing.Union["LoginConfig", typing.Dict[str, typing.Any]],
+                login_config: typing.Union[LoginConfig, typing.Dict[str, typing.Any]],
                 destination_tag: typing.Optional[builtins.str] = None,
             ) -> None:
                 ...
@@ -257,7 +257,7 @@ class DockerImageDeployment(
                 id: builtins.str,
                 *,
                 destination: Destination,
-                source: "Source",
+                source: Source,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -280,7 +280,7 @@ class DockerImageDeploymentProps:
         :param source: Source of the image to deploy.
         '''
         if __debug__:
-            def stub(*, destination: Destination, source: "Source") -> None:
+            def stub(*, destination: Destination, source: Source) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
             check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
